# SNaP OneDrive Report Aggregator
Utility for ModelTB.org team. Aggregates SNaP reports to a single file.

## Prerequisites
1. Gain access to the following OneDrive folders: TODO
2. Install OneDrive Sync: URL TODO
3. Install Python3: URL TODO

## Installation
1. Ensure that all prerequisites are complete.
2. Open terminal (Instructions: Mac | Windows)  <-- 2 URLS TODO
3. Enter command: `python3 -m pip install --user pipx`
4. Enter command: `python3 -m pipx ensurepath`
5. Restart terminal
6. Enter command: `pipx install snap-tam`

## Running
1. Open terminal
2. Enter command: `snap-tam`
